summaryrefslogtreecommitdiffstats
path: root/tdeui/kcolordialog.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:13:01 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:13:01 -0600
commitdeac2ca49faed824fe83066080714eb6d653615b (patch)
tree8b5bf97c5acaaf5285985b87fa76dbea0f35e4fa /tdeui/kcolordialog.h
parent0c9d97065a3d6ceb12d687555a1a33d90db96238 (diff)
downloadtdelibs-deac2ca49faed824fe83066080714eb6d653615b.tar.gz
tdelibs-deac2ca49faed824fe83066080714eb6d653615b.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'tdeui/kcolordialog.h')
-rw-r--r--tdeui/kcolordialog.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/tdeui/kcolordialog.h b/tdeui/kcolordialog.h
index 20c9f799d..7f04d6d17 100644
--- a/tdeui/kcolordialog.h
+++ b/tdeui/kcolordialog.h
@@ -39,7 +39,7 @@
class TQComboBox;
class TQLineEdit;
-class KListBox;
+class TDEListBox;
class KPalette;
class KColorCells;
@@ -99,7 +99,7 @@ class KValueSelectorPrivate;
* @see KHSSelector, KColorDialog
* @author Martin Jones (mjones@kde.org)
*/
-class TDEUI_EXPORT KValueSelector : public KSelector
+class TDEUI_EXPORT KValueSelector : public TDESelector
{
Q_OBJECT
@@ -132,7 +132,7 @@ protected:
virtual void resizeEvent( TQResizeEvent * );
/**
* Reimplemented from KSelector. The drawing is
* buffered in a pixmap here. As real drawing
* routine, drawPalette() is used.
*/
@@ -229,7 +229,7 @@ protected:
TQComboBox *combo;
KColorCells *cells;
TQScrollView *sv;
- KListBox *mNamedColorList;
+ TDEListBox *mNamedColorList;
KPalette *mPalette;
int mMinWidth;
int mCols;
@@ -132,7 +132,7 @@ protected:
virtual void resizeEvent( TQResizeEvent * );
/**
- * Reimplemented from KSelector. The drawing is
+ * Reimplemented from TDESelector. The drawing is
* buffered in a pixmap here. As real drawing
* routine, drawPalette() is used.